pub enum CompressionCodec {
Uncompressed = 0,
Snappy = 1,
Gzip = 2,
Lzo = 3,
Brotli = 4,
Lz4 = 5,
Zstd = 6,
}Expand description
Supported compression algorithms.
Codecs added in 2.4 can be read by readers based on 2.4 and later. Codec support may vary between readers based on the format version and libraries available at runtime. Gzip, Snappy, and LZ4 codecs are widely available, while Zstd and Brotli require additional libraries.
Variants
Implementations
Sourceimpl CompressionCodec
impl CompressionCodec
pub fn write_to_out_protocol( &self, o_prot: &mut dyn TOutputProtocol, ) -> Result<()>
pub fn read_from_in_protocol( i_prot: &mut dyn TInputProtocol, ) -> Result<CompressionCodec>