pub struct NullType {}Expand description
Logical type to annotate a column that is always null.
Sometimes when discovering the schema of existing data, values are always null and the physical type can’t be determined. This annotation signals the case where the physical type was guessed from all null values.
Implementations
Sourceimpl NullType
impl NullType
pub fn new() -> NullType
pub fn read_from_in_protocol( i_prot: &mut dyn TInputProtocol, ) -> Result<NullType>
pub fn write_to_out_protocol( &self, o_prot: &mut dyn TOutputProtocol, ) -> Result<()>